@@ -3,13 +3,15 @@ Main interface for kinesisanalytics service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.kinesisanalytics import KinesisAnalyticsClient
+    from mypy_boto3_kinesisanalytics import KinesisAnalyticsClient
 
     session = boto3.Session()
 
     client: KinesisAnalyticsClient = boto3.client("kinesisanalytics")
     session_client: KinesisAnalyticsClient = session.client("kinesisanalytics")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
